pub struct CollectionEntry<K> { /* private fields */ }Expand description
Represents an entry in a collection used to build a frozen collection.
Implementations
Sourceimpl<K> CollectionEntry<K>
impl<K> CollectionEntry<K>
Sourcepub const fn map_entry(
key: K,
key_expr: Expr,
value_expr: Expr,
) -> CollectionEntry<K>
pub const fn map_entry( key: K, key_expr: Expr, value_expr: Expr, ) -> CollectionEntry<K>
Creates a new CollectionEntry for a map, using the specified key, key expression, and value expression.
Sourcepub fn set_entry(value: K, value_expr: Expr) -> CollectionEntry<K>
pub fn set_entry(value: K, value_expr: Expr) -> CollectionEntry<K>
Creates a new CollectionEntry for a set, using the specified value and value expression.