pub struct FzHashSet<T, BH = RandomState> { /* private fields */ }Expand description
A set optimized for fast read access with hashable values.
A frozen collection differs from the traditional Rust collections, such as
HashMap and HashSet types in three
key ways. First, creating a frozen collection performs an analysis over the input data to
determine the best implementation strategy. Depending on the situation, this analysis is
performed at build time or runtime, and it can take a relatively long time when a collection is
very large. Second, once created, the keys in frozen collections are immutable. And third,
querying a frozen collection is typically considerably faster, which is the whole point.
This type requires that the keys
implement the Eq and Hash traits. This can frequently be achieved by
using #[derive(PartialEq, Eq, Hash)]. If you implement these yourself,
it is important that the following property holds:
k1 == k2 -> hash(k1) == hash(k2)In other words, if two keys are equal, their hashes must be equal. Violating this property is a logic error.
It is also a logic error for a key to be modified in such a way that the key’s
hash, as determined by the Hash trait, or its equality, as determined by
the Eq trait, changes while it is in the collection. This is normally only
possible through core::cell::Cell, core::cell::RefCell, global state, I/O,
or unsafe code.
The behavior resulting from either logic error can include panics, incorrect results, memory leaks, and non-termination.
Alternate Choices
If your values are integers or enum variants, you should use the FzScalarSet type instead.
If your values are strings, you should use the FzStringSet type instead. Both of these will
deliver better performance since they are specifically optimized for those value types.
If your values are known at compile time, consider using the various fz_*_set macros instead of
this type as they generally perform better.
Implementations
Sourceimpl<T, BH> FzHashSet<T, BH>where
BH: BuildHasher,
impl<T, BH> FzHashSet<T, BH>where
BH: BuildHasher,
Sourcepub fn with_hasher(entries: Vec<T>, bh: BH) -> FzHashSet<T, BH>
pub fn with_hasher(entries: Vec<T>, bh: BH) -> FzHashSet<T, BH>
Creates a new frozen set which uses the given hash builder to hash values. If the input contains duplicate value, the latter one in the input is used and all former ones are discarded.